%define realname OpenIPMI
%define _disable_ld_no_undefined 1

#The lib naming in OpenIPMI 1.x
%define oldlibname %mklibname %realname 1

Name: 		openipmi
Summary: 	Library interface to OpenIPMI
Version:	2.0.35
Release:	%mkrel 2
License: 	LGPLv2+
Group: 		System/Kernel and hardware
URL: 		https://openipmi.sourceforge.net/
Source: 	https://downloads.sourceforge.net/openipmi/%{realname}-%{version}.tar.gz
Patch1:		0001-man.patch
BuildRequires:	swig >= 1.3
BuildRequires:	gdbm-devel
BuildRequires:	perl-devel
BuildRequires:	pkgconfig(python3)
BuildRequires:	pkgconfig(popt)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(netsnmp)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(readline)
BuildRequires:	tcl
BuildRequires:	pkgconfig(tcl)
BuildRequires:	tkinter3
BuildRequires:	tk
BuildRequires:	pkgconfig(tk)
Requires(pre):	rpm-helper
Requires(post):	rpm-helper

# Perl is usually installed in /usr/lib, not /usr/lib64 on 64-bit platforms.
#define perl_libdir %%{_exec_prefix}/lib

%description 
This package contains a shared library implementation of IPMI and the
basic tools used with OpenIPMI.

%package devel
Summary:	Development files for OpenIPMI
Group:		Development/C
Requires:	%{name} = %{version}-%{release}
Requires:	%{name}-lanserv = %{version}-%{release}
Requires:	%{name}-ui = %{version}-%{release}
Requires:	tcl-%{name} = %{version}-%{release}

%description devel
Contains additional files need for a developer to create applications
and/or middleware that depends on libOpenIPMI

%package -n perl-%{name}
Summary:	Perl interface for OpenIPMI
Group:		Development/Perl
Requires:	%{name} = %{version}-%{release}

%description -n perl-%{name}
A Perl interface for OpenIPMI.

%package -n python3-%{name}
Summary:	Python 3 interface for OpenIPMI
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
%{?python_provide:%python_provide python3-%{name}}

%description -n python3-%{name}
A Python 3 interface for OpenIPMI.

%package -n tcl-%{name}
Summary:	TCL interface for OpenIPMI
Group:		Development/Other
Requires:	%{name} = %{version}-%{release}
Requires:	tcl

%description -n tcl-%{name}
A TCL interface for OpenIPMI.

%package gui
Summary:	GUI (in python) for OpenIPMI
Group:		System/Kernel and hardware
Requires:	python3-%{name} = %{version}-%{release}
# mga#19117
Requires:	tix
Requires:	tkinter3

%description gui
A GUI interface for OpenIPMI.  Written in python an requiring wxWidgets.

%package ui
Summary:	User Interface (ui)
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}-%{release}

%description ui
This package contains a user interface

%package lanserv
Summary:	Emulates an IPMI network listener
Group:		System/Kernel and hardware
Requires:	%{name} = %{version}-%{release}

%description lanserv
This package contains a network IPMI listener.

%prep
%setup -q -n %{realname}-%{version}
%autopatch -p1

sed -i 's|import Tix|import tix|' configure.ac

%build
export PYTHONDONTWRITEBYTECODE=
%configure \
	--disable-static \
	--with-perlinstall=%{perl_vendorarch} \
	--with-pythoninstall=%{python3_sitearch} \
	--with-python=%{__python3} \
	--with-tkinter=yes \
	--with-pythonusepthreads=yes \
	--with-perlusepthreads=yes \
	--with-tcl=yes \
	--with-tclcflags="-I %{_includedir}"

make

%install
%make_install PYTHON_GUI_DIR=openipmigui

find %{buildroot} -name '*.la' -delete

install -m755 ipmi.init -D %{buildroot}%{_sysconfdir}/init.d/ipmi
install -m644 ipmi.sysconf -D %{buildroot}%{_sysconfdir}/sysconfig/ipmi

# python shebangs
%py3_shebang_fix %{buildroot}%{_bindir}/openipmigui

%preun
%_preun_service ipmi

%postun
%_post_service ipmi

%files
%{_libdir}/libOpenIPMIcmdlang.so.*
%{_libdir}/libOpenIPMIglib.so.*
%{_libdir}/libOpenIPMIposix.so.*
%{_libdir}/libOpenIPMIpthread.so.*
%{_libdir}/libOpenIPMI.so.*
%{_libdir}/libOpenIPMIutils.so.*
%{_sysconfdir}/init.d/ipmi
%config(noreplace) %{_sysconfdir}/sysconfig/ipmi
%doc FAQ README README.Force
%doc README.MotorolaMXP

%files -n perl-%{name}
%{perl_vendorarch}/OpenIPMI.pm
%{perl_vendorarch}/auto/OpenIPMI
%doc swig/OpenIPMI.i swig/perl/sample swig/perl/ipmi_powerctl

%files -n python3-%{name}
%{python3_sitearch}/*OpenIPMI.*
%{python3_sitearch}/__pycache__/*
%doc swig/OpenIPMI.i

%files -n tcl-%{name}
%{_libdir}/*OpenIPMItcl.so.*

%files gui
%{python3_sitearch}/openipmigui/
%{_bindir}/openipmigui

%files devel
%{_includedir}/OpenIPMI/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%doc doc/IPMI.pdf

%files ui
%{_bindir}/ipmi_ui
%{_bindir}/ipmicmd
%{_bindir}/openipmicmd
%{_bindir}/ipmish
%{_bindir}/openipmish
%{_bindir}/solterm
%{_bindir}/rmcp_ping
%{_bindir}/openipmi_eventd
%{_libdir}/libOpenIPMIui.so.*
%{_mandir}/man1/ipmi_ui.1*
%{_mandir}/man1/openipmicmd.1*
%{_mandir}/man1/openipmish.1*
%{_mandir}/man1/openipmigui.1*
%{_mandir}/man1/solterm.1*
%{_mandir}/man1/rmcp_ping.1*
%{_mandir}/man1/openipmi_eventd.1*
%{_mandir}/man7/ipmi_cmdlang.7*
%{_mandir}/man7/openipmi_conparms.7*

%files lanserv
%config(noreplace) %{_sysconfdir}/ipmi/ipmisim1.emu
%config(noreplace) %{_sysconfdir}/ipmi/lan.conf
%{_bindir}/ipmilan
%{_bindir}/ipmi_sim
%{_bindir}/sdrcomp
%{_libdir}/libIPMIlanserv.so.*
%{_mandir}/man8/ipmilan.8*
%{_mandir}/man1/ipmi_sim.1*
%{_mandir}/man5/ipmi_lan.5*
%{_mandir}/man5/ipmi_sim_cmd.5*


%changelog
* Tue Mar 04 2025 wally <wally> 2.0.35-2.mga10
+ Revision: 2160410
- rebuild for python3.13

* Mon Jul 08 2024 papoteur <papoteur> 2.0.35-1.mga10
+ Revision: 2080338
- new version 2.0.35

* Thu Dec 28 2023 daviddavid <daviddavid> 2.0.34-2.mga10
+ Revision: 2022834
- rebuild for py3.12

* Fri Sep 29 2023 daviddavid <daviddavid> 2.0.34-1.mga10
+ Revision: 1992179
- new version: 2.0.34

* Thu Sep 28 2023 daviddavid <daviddavid> 2.0.33-2.mga10
+ Revision: 1991951
- gui python bindings requires tix and tkinter3 (mga#19117)
- do not mark manpages as %%doc
- fix owner of pkgconfig dir

* Sat Dec 10 2022 ghibo <ghibo> 2.0.33-1.mga9
+ Revision: 1920304
- Update to release 2.0.33

* Thu Aug 04 2022 tv <tv> 2.0.29-3.mga9
+ Revision: 1875072
- Rebuild for perl-5.36
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Feb 01 2022 mrambo3501 <mrambo3501> 2.0.29-1.mga9
+ Revision: 1770827
- version 2.0.29
- delete upstreamed Patch2
+ wally <wally>
- rebuild for openssl 3.0.0

* Thu Mar 25 2021 daviddavid <daviddavid> 2.0.28-4.mga9
+ Revision: 1710171
- rebuild for python 3.9

* Tue Nov 03 2020 akien <akien> 2.0.28-3.mga8
+ Revision: 1642002
- Rebuild for new libnetsnmp

* Sat Jul 18 2020 tv <tv> 2.0.28-2.mga8
+ Revision: 1606961
- rebuild for perl-5.32 (binary package w/o a dep on libperl.so

* Sun Feb 23 2020 daviddavid <daviddavid> 2.0.28-1.mga8
+ Revision: 1549621
- new version: 2.0.28
- port to python3
- drop python2 support
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sat Dec 29 2018 luigiwalser <luigiwalser> 2.0.25-4.mga7
+ Revision: 1346030
- rebuild for net-snmp

* Mon Oct 08 2018 tv <tv> 2.0.25-3.mga7
+ Revision: 1318636
+ rebuild (emptylog)

* Fri Aug 24 2018 daviddavid <daviddavid> 2.0.25-1.mga7
+ Revision: 1253801
- new version: 2.0.25
- remove no more needed patch
- rename python-openipmi to python2-openipmi

* Sun Jun 17 2018 luigiwalser <luigiwalser> 2.0.24-2.mga7
+ Revision: 1237487
- rebuild for gdbm

* Fri Sep 01 2017 guillomovitch <guillomovitch> 2.0.24-1.mga7
+ Revision: 1150468
- new version 2.0.24

* Sat Jun 18 2016 pterjan <pterjan> 2.0.21-12.mga6
+ Revision: 1022169
- Rebuild for perl 5.22.2

* Tue Feb 16 2016 umeabot <umeabot> 2.0.21-11.mga6
+ Revision: 961947
- Mageia 6 Mass Rebuild

* Mon Oct 05 2015 daviddavid <daviddavid> 2.0.21-10.mga6
+ Revision: 886412
- rebuild for new tcl/tk 8.6.4
- use new python2 macros

* Sat Jun 27 2015 tv <tv> 2.0.21-9.mga6
+ Revision: 846152
- rebuild with soname-ified perl

* Tue Jun 23 2015 fwang <fwang> 2.0.21-8.mga6
+ Revision: 840521
- rebuild for new perl

* Wed Oct 15 2014 umeabot <umeabot> 2.0.21-7.mga5
+ Revision: 742181
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.0.21-6.mga5
+ Revision: 727522
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.0.21-5.mga5
+ Revision: 683215
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 jquelin <jquelin> 2.0.21-4.mga5
+ Revision: 632360
- perl 5.20.0 rebuild

* Tue Jun 03 2014 pterjan <pterjan> 2.0.21-3.mga5
+ Revision: 632307
- Rebuild for perl 5.20
- Rebuild for new Python

* Thu Feb 06 2014 fwang <fwang> 2.0.21-1.mga5
+ Revision: 584632
- update file list
- new version 2.0.21

* Sat Oct 19 2013 umeabot <umeabot> 2.0.18-6.mga4
+ Revision: 524164
- Mageia 4 Mass Rebuild

* Wed May 29 2013 fwang <fwang> 2.0.18-5.mga4
+ Revision: 430423
- rebuild for new perl

* Sun Jan 13 2013 umeabot <umeabot> 2.0.18-4.mga3
+ Revision: 362042
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 05 2011 fwang <fwang> 2.0.18-3.mga3
+ Revision: 176943
- rebuild for new gdbm
- disable static
- cleanup spec
  do not ship .la files
- imported package openipmi


* Mon Jul 18 2011 Oden Eriksson <oeriksson@mandriva.com> 2.0.18-2mdv2011
+ Revision: 690300
- rebuilt against new net-snmp libs

* Fri Apr 22 2011 Funda Wang <fwang@mandriva.org> 2.0.18-1
+ Revision: 656614
- new version 2.0.18

* Thu Nov 04 2010 Götz Waschk <waschk@mandriva.org> 2.0.16-8mdv2011.0
+ Revision: 593319
- rebuild for new python 2.7

* Tue Oct 12 2010 Funda Wang <fwang@mandriva.org> 2.0.16-7mdv2011.0
+ Revision: 585011
- rebuild

* Sat Sep 18 2010 Funda Wang <fwang@mandriva.org> 2.0.16-6mdv2011.0
+ Revision: 579343
- add more missing requires

* Sat Sep 18 2010 Funda Wang <fwang@mandriva.org> 2.0.16-5mdv2011.0
+ Revision: 579337
- add missing requries

* Sun Aug 01 2010 Funda Wang <fwang@mandriva.org> 2.0.16-4mdv2011.0
+ Revision: 564323
- rebuild for perl 5.12.1

* Thu Jul 22 2010 Jérôme Quelin <jquelin@mandriva.org> 2.0.16-3mdv2011.0
+ Revision: 556778
- perl 5.12 rebuild

* Thu Apr 08 2010 Eugeni Dodonov <eugeni@mandriva.com> 2.0.16-2mdv2010.1
+ Revision: 533229
- Rebuild for openssl 1.0.0.

* Tue Mar 30 2010 Pascal Terjan <pterjan@mandriva.org> 2.0.16-1mdv2010.1
+ Revision: 530062
- Generate .pyc as it would need heavy patching of Makefiles to get rid of them
- Import update to 2.0.16 by Oden
- Fix for new libtool
- Fixes for python 2.6

  + Oden Eriksson <oeriksson@mandriva.com>
    - rebuilt for 2010.1
    - rebuilt against openssl-0.9.8m
    - rebuilt against new net-snmp libs

* Fri Dec 05 2008 Adam Williamson <awilliamson@mandriva.org> 2.0.14-4mdv2009.1
+ Revision: 310410
- rebuild for new tcl

* Mon Sep 15 2008 Oden Eriksson <oeriksson@mandriva.com> 2.0.14-3mdv2009.0
+ Revision: 284856
- fix build
- fix deps

  + Erwan Velu <erwan@mandriva.org>
    - Adding missing python dir for openipmigui. Related to #42911

* Sun Jul 27 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.0.14-1mdv2009.0
+ Revision: 250705
- update to new version 2.0.14
- new license policy
- add missing buildrequire on tcl-devel
- spec file clean
- do not package COPYING and INSTALL files
- use %%define _disable_ld_no_undefined 1 to make it compile
- adjust configure options

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers
    - normalize call to ldconfig in %%post/%%postun

* Thu Feb 07 2008 Erwan Velu <erwan@mandriva.org> 2.0.13-2mdv2008.1
+ Revision: 163391
- IPMI is nor more necessary

* Tue Feb 05 2008 Erwan Velu <erwan@mandriva.org> 2.0.13-1mdv2008.1
+ Revision: 162640
- This file doesn't exists anymore
- Removing python gui directory
- Fixing gui install
- import openipmi


